@@ -8,10 +8,17 @@ def _get_client_id_request_info() -> dict:
     }
 
 
-def _get_users_request_info(limit: int) -> dict:
+def _get_users_request_info(limit: int, page_offset: int) -> dict:
     return {
         "endpoint": "users",
-        "params": {"max": limit},
+        "params": {"max": limit, "first": page_offset},
+        "url_key": "keycloak_admin"
+    }
+
+
+def _get_user_count_request_info() -> dict:
+    return {
+        "endpoint": f"users/count",
         "url_key": "keycloak_admin"
     }
 
