@@ -1,5 +1,3 @@
-import json
-
 from algora.api.service.backtest.enum import BacktestStatus
 from algora.api.service.backtest.model import BacktestRequest
 
@@ -19,7 +17,7 @@ def _get_backtests_request_info() -> dict:
 def _create_backtest_request_info(request: BacktestRequest) -> dict:
     return {
         "endpoint": "config/backtest",
-        "json": json.loads(request.json())
+        "json": request.request_dict()
     }
 
 
